#!/usr/bin/env python3

"""Module containing the Template class and the command line interface."""
import argparse
import pandas as pd
import numpy as np
import igraph as ig
import os
import shutil
from pathlib import PurePath
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import  settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


# 1. Rename class as required
class Template(BiobbObject):
    """
    | biobb_template Template
    | Short description for the `template <http://templatedocumentation.org>`_ module in Restructured Text (reST) syntax. Mandatory.
    | Long description for the `template <http://templatedocumentation.org>`_ module in Restructured Text (reST) syntax. Optional.

    Args:        
        input_file_path1 (str): Description for the first input file path. File type: input. `Sample file <https://urlto.sample>`_. Accepted formats: top (edam:format_3881).
        input_file_path2 (str) (Optional): Description for the second input file path (optional). File type: input. `Sample file <https://urlto.sample>`_. Accepted formats: dcd (edam:format_3878).
        output_file_path (str): Description for the output file path. File type: output. `Sample file <https://urlto.sample>`_. Accepted formats: zip (edam:format_3987).
        properties (dic):
            * **boolean_property** (*bool*) - (True) Example of boolean property.
            * **executable_binary_property** (*str*) - ("zip") Example of executable binary property.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_template.template.template import template

            prop = { 
                'boolean_property': True 
            }
            template(input_file_path1='/path/to/myTopology.top',
                    output_file_path='/path/to/newCompressedFile.zip',
                    input_file_path2='/path/to/mytrajectory.dcd',
                    properties=prop)

    Info:
        * wrapped_software:
            * name: Zip
            * version: >=3.0
            * license: BSD 3-Clause
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    # 2. Adapt input and output file paths as required. Include all files, even optional ones
    def __init__(self, input_file_path1, output_file_path, 
                input_file_path2, input_file_path3,  properties = None, **kwargs) -> None:
        properties = properties or {}

        # 2.0 Call parent class constructor
        super().__init__(properties)

        # 2.1 Modify to match constructor parameters
        # Input/Output files
        self.io_dict = { 
            'in': { 'input_file_path1': input_file_path1, 'input_file_path2': input_file_path2, 'input_file_path3': input_file_path3 }, 
            'out': { 'output_file_path': output_file_path } 
        }

        # 3. Include all relevant properties here as 
        # self.property_name = properties.get('property_name', property_default_value)

        # Properties specific for BB
        self.curated = properties.get('curated', False)
        self.algorithm = properties.get('algorithm', 's')
        self.disease = properties.get('disease', '')
        self.hippie_score = properties.get('hippie_score', 0.0)
        self.disgenet_score = properties.get('disgenet_score', 0.0)
        self.scoring_mode = properties.get('scoring_mode', 'dis')
        self.properties = properties

        # Check the properties
        self.check_properties(properties)

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Template <template.template.Template>` object."""

        # 4. Setup Biobb
        if self.check_restart(): return 0
        self.stage_files()

        # Creating temporary folder
        self.tmp_folder = fu.create_unique_dir()
        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)

        # 5. Include here all mandatory input files
        # Copy input_file_path1 to temporary folder
        shutil.copy(self.io_dict['in']['input_file_path1'], self.tmp_folder)
#        shutil.copy(self.io_dict['in']['input_file_path2'], self.tmp_folder)
#        shutil.copy(self.io_dict['in']['input_file_path3'], self.tmp_folder)

        # 6. Prepare the command line parameters as instructions list
        instructions = ['-j']
        if self.algorithm:
            instructions.append('-a')
            fu.log('Appending mandatory algorithm prop', self.out_log, self.global_log)
        elif self.disease:
            instructions.append('-d')
            fu.log('Appending mandatory disease code', self.out_log, self.global_log)
        elif self.hippie_score:
            instruction.append('-hs')
            fu.log('Appending optional Hippie Score', self.out_log, self.global_log)
        elif self.hippie_score:
            instruction.append('-ds')
            fu.log('Appending optional Disgenet Score', self.out_log, self.global_log)
        elif self.hippie_score:
            instruction.append('-m')
            fu.log('Appending optional scoring mode', self.out_log, self.global_log)
        elif self.hippie_score:
            instruction.append('-c')
            fu.log('Appending optional curated opt', self.out_log, self.global_log)

        # 7. Build the actual command line as a list of items (elements order will be maintained)
        self.cmd = [self.executable_binary_property,
               ' '.join(instructions), 
               self.io_dict['out']['output_file_path'],
               str(PurePath(self.tmp_folder).joinpath(PurePath(self.io_dict['in']['input_file_path1']).name))]
        fu.log('Creating command line with instructions and required arguments', self.out_log, self.global_log)

        # 8. Repeat for optional input files if provided
        if self.io_dict['in']['input_file_path2']:
            # Copy input_file_path2 to temporary folder
            shutil.copy(self.io_dict['in']['input_file_path2'], self.tmp_folder)
            # Append optional input_file_path2 to cmd
            self.cmd.append(str(PurePath(self.tmp_folder).joinpath(PurePath(self.io_dict['in']['input_file_path2']).name)))
            fu.log('Appending optional argument to command line', self.out_log, self.global_log)
        elif self.io_dict['in']['input_file_path3']:
            # Copy input_file_path2 to temporary folder
            shutil.copy(self.io_dict['in']['input_file_path3'], self.tmp_folder)
            # Append optional input_file_path2 to cmd
            self.cmd.append(str(PurePath(self.tmp_folder).joinpath(PurePath(self.io_dict['in']['input_file_path3']).name)))
            fu.log('Appending optional argument to command line', self.out_log, self.global_log)

        # 9. Uncomment to check the command line 
        print(' '.join(cmd))

        # Run Biobb block
        self.run_biobb()

        # Remove temporary file(s)
        if self.remove_tmp: 
            self.tmp_files.append(self.tmp_folder)
            self.remove_tmp_files()

        return self.return_code

def template(input_file_path1: str, output_file_path: str, input_file_path2: str, input_file_path3: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Template <template.template.Template>` class and
    execute the :meth:`launch() <template.template.Template.launch>` method."""

    return Template(input_file_path1=input_file_path1, 
                    output_file_path=output_file_path,
                    input_file_path2=input_file_path2,
                    input_file_path3=input_file_path3,
                    properties=properties, **kwargs).launch()

def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Description for the template module.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('--config', required=False, help='Configuration file')

    # 10. Include specific args of each building block following the examples. They should match step 2
    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('--input_file_path1', required=True, help='Description for the first input file path.')
    parser.add_argument('--input_file_path2', required=False, help='Description for the second input file path.')
    parser.add_argument('--input_file_path3', required=False, help='Description for the second input file path.')
    required_args.add_argument('--output_file_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    # 11. Adapt to match Class constructor (step 2)
    # Specific call of each building block
    template(input_file_path1=args.input_file_path1, 
             output_file_path=args.output_file_path, 
             input_file_path2=args.input_file_path2,
             input_file_path3=args.input_file_path3,
             properties=properties)

if __name__ == '__main__':
    main()

# 12. Complete documentation strings



#!/usr/bin/env python3

"""Module containing the TemplateContainer class and the command line interface."""
import argparse
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import  settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


# 1. Rename class as required
class TemplateContainer(BiobbObject):
    """
    | biobb_template TemplateContainer
    | Short description for the `template container <http://templatedocumentation.org>`_ module in Restructured Text (reST) syntax. Mandatory.
    | Long description for the `template container <http://templatedocumentation.org>`_ module in Restructured Text (reST) syntax. Optional.

    Args:
        input_file_path1 (str): Description for the first input file path. File type: input. `Sample file <https://urlto.sample>`_. Accepted formats: top (edam:format_3881).
        input_file_path2 (str) (Optional): Description for the second input file path (optional). File type: input. `Sample file <https://urlto.sample>`_. Accepted formats: dcd (edam:format_3878).
        output_file_path (str): Description for the output file path. File type: output. `Sample file <https://urlto.sample>`_. Accepted formats: zip (edam:format_3987).
        properties (dic):
            * **boolean_property** (*bool*) - (True) Example of boolean property.
            * **executable_binary_property** (*str*) - ("zip") Example of executable binary property.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
            * **container_path** (*str*) - (None) Container path definition.
            * **container_image** (*str*) - ('mmbirb/zip:latest') Container image definition.
            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
            * **container_working_dir** (*str*) - (None) Container working directory definition.
            * **container_user_id** (*str*) - (None) Container user_id definition.
            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_template.template.template_container import template_container

            prop = { 
                'boolean_property': True,
                'container_path': 'docker',
                'container_image': 'mmbirb/zip:latest',
                'container_volume_path': '/tmp'
            }
            template_container(input_file_path1='/path/to/myTopology.top',
                            output_file_path='/path/to/newCompressedFile.zip',
                            input_file_path2='/path/to/mytrajectory.dcd',
                            properties=prop)

    Info:
        * wrapped_software:
            * name: Zip
            * version: >=3.0
            * license: BSD 3-Clause
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    # 2. Adapt input and output file paths as required. Include all files, even optional ones
    def __init__(self, input_file_path1, output_file_path, 
                input_file_path2 = None, properties = None, **kwargs) -> None:
        properties = properties or {}

        # 2.0 Call parent class constructor
        super().__init__(properties)

        # 2.1 Modify to match constructor parameters
        # Input/Output files
        self.io_dict = { 
            'in': { 'input_file_path1': input_file_path1, 'input_file_path2': input_file_path2 }, 
            'out': { 'output_file_path': output_file_path } 
        }

        # 3. Include all relevant properties here as 
        # self.property_name = properties.get('property_name', property_default_value)

        # Properties specific for BB
        self.boolean_property = properties.get('boolean_property', True)
        self.executable_binary_property = properties.get('executable_binary_property', 'zip')
        self.properties = properties

        # Check the properties
        self.check_properties(properties)

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`TemplateContainer <template.template_container.TemplateContainer>` object."""
        
        # 4. Setup Biobb
        if self.check_restart(): return 0
        self.stage_files()

        # Creating temporary folder
        self.tmp_folder = fu.create_unique_dir()
        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)

        # 5. Prepare the command line parameters as instructions list
        instructions = ['-j']
        if self.boolean_property:
            instructions.append('-v')
            fu.log('Appending optional boolean property', self.out_log, self.global_log)

        # 6. Build the actual command line as a list of items (elements order will be maintained)
        self.cmd = [self.executable_binary_property,
               ' '.join(instructions), 
               self.stage_io_dict['out']['output_file_path'],
               self.stage_io_dict['in']['input_file_path1']]
        fu.log('Creating command line with instructions and required arguments', self.out_log, self.global_log)

        # 7. Repeat for optional input files if provided
        if self.stage_io_dict['in']['input_file_path2']:
            # Append optional input_file_path2 to cmd
            self.cmd.append(self.stage_io_dict['in']['input_file_path2'])
            fu.log('Appending optional argument to command line', self.out_log, self.global_log)

        # 8. Uncomment to check the command line 
        # print(' '.join(cmd))

        # Run Biobb block
        self.run_biobb()

        # Copy files to host
        self.copy_to_host()

        # Remove temporary file(s)
        if self.remove_tmp and self.stage_io_dict["unique_dir"]:
            self.tmp_files.append(self.stage_io_dict.get("unique_dir"))
            self.remove_tmp_files()

        return self.return_code

def template_container(input_file_path1: str, output_file_path: str, input_file_path2: str = None, properties: dict = None, **kwargs) -> int:
    """Create :class:`TemplateContainer <template.template_container.TemplateContainer>` class and
    execute the :meth:`launch() <template.template_container.TemplateContainer.launch>` method."""

    return TemplateContainer(input_file_path1=input_file_path1, 
                            output_file_path=output_file_path,
                            input_file_path2=input_file_path2,
                            properties=properties, **kwargs).launch()

def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Description for the template container module.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('--config', required=False, help='Configuration file')

    # 10. Include specific args of each building block following the examples. They should match step 2
    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('--input_file_path1', required=True, help='Description for the first input file path. Accepted formats: top.')
    parser.add_argument('--input_file_path2', required=False, help='Description for the second input file path (optional). Accepted formats: dcd.')
    required_args.add_argument('--output_file_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    # 11. Adapt to match Class constructor (step 2)
    # Specific call of each building block
    template_container(input_file_path1=args.input_file_path1, 
                      output_file_path=args.output_file_path, 
                      input_file_path2=args.input_file_path2, 
                      properties=properties)

if __name__ == '__main__':
    main()

# 13. Complete documentation strings


#!/usr/bin/env python3

"""Module containing the Template class and the command line interface."""
import argparse
import pandas as pd
import numpy as np
#import igraph as ig
import os
import shutil
from pathlib import PurePath
from biobb_guild.guild.common import *
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import  settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


# 1. Rename class as required
class ParseHippie(BiobbObject):
    """
    | biobb_template Parse Hippie

    Args:        
        input_file_path1 (str): Hippie Database. Accepted formats: txt.
        input_file_path2 (str): Hippie Genes
        output_file_path (str): Description for the output file path. File type: output. `Sample file <https://urlto.sample>`_. Accepted formats: zip (edam:format_3987).
        properties (dic):
            * **boolean_property** (*bool*) - (True) Example of boolean property.
            * **executable_binary_property** (*str*) - ("zip") Example of executable binary property.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_template.template.template import template

            prop = { 
                'boolean_property': True 
            }
            template(input_file_path1='/path/to/myTopology.top',
                    output_file_path='/path/to/newCompressedFile.zip',
                    input_file_path2='/path/to/mytrajectory.dcd',
                    properties=prop)

    Info:
        * wrapped_software:
            * name: Zip
            * version: >=3.0
            * license: BSD 3-Clause
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    # 2. Adapt input and output file paths as required. Include all files, even optional ones
    def __init__(self, input_file_path1, input_file_path2, output_sif_path,
                properties = None, **kwargs) -> None:
        properties = properties or {}

        # 2.0 Call parent class constructor
        super().__init__(properties)

        # 2.1 Modify to match constructor parameters
        # Input/Output files
        self.io_dict = { 
                'in': { 'input_file_path1': input_file_path1, 'input_file_path2': input_file_path2 }, 
            'out': { 'output_sif_path': output_sif_path } 
        }

        # 3. Include all relevant properties here as 
        # self.property_name = properties.get('property_name', property_default_value)

        # Properties specific for BB
        #self.curated = properties.get('curated', False)
        #self.disease = properties.get('disease', '')
        self.hippie_score = properties.get('hippie_score', 0.0)
        self.disgenet_score = properties.get('disgenet_score', 0.0)
        #self.scoring_mode = properties.get('scoring_mode', 'dis')
        self.properties = properties

        # Check the properties
        self.check_properties(properties)

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Template <template.template.Template>` object."""

        # 4. Setup Biobb
        if self.check_restart(): return 0
        self.stage_files()

        # Creating temporary folder
        self.tmp_folder = fu.create_unique_dir()
        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)

        # 5. Include here all mandatory input files
        # Copy input_file_path1 to temporary folder
#        shutil.copy(self.io_dict['in']['input_file_path1'], self.tmp_folder)
#        shutil.copy(self.io_dict['in']['input_file_path2'], self.tmp_folder)
#        shutil.copy(self.io_dict['in']['input_file_path3'], self.tmp_folder)
        check_output(self.io_dict['out']['output_sif_path'], "output_sif", self.out_log,self.__class__.__name__)
        parse_hippie(self.io_dict['in']['input_file_path1'], self.io_dict['in']['input_file_path2'], self.hippie_score, self.io_dict['out']['output_sif_path'], self.out_log, self.global_log) 

        return 0

def parsehippie(input_file_path1: str, output_sif_path: str, input_file_path2: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Template <template.template.Template>` class and
    execute the :meth:`launch() <template.template.Template.launch>` method."""

    return ParseHippie(input_file_path1=input_file_path1, 
                    output_sif_path=output_sif_path,
                    input_file_path2=input_file_path2,
                    properties=properties, **kwargs).launch()

def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Description for the template module.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('-c','--config', required=True, help='Configuration file')

    # 10. Include specific args of each building block following the examples. They should match step 2
    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('-i','--input_db', required=True, help='Description for the first input file path.')
    parser.add_argument('-g','--input_genes', required=True, help='Description for the second input file path.')
    required_args.add_argument('-o','--output_sif_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    # 11. Adapt to match Class constructor (step 2)
    # Specific call of each building block
    parsehippie(input_file_path1=args.input_db, 
             output_sif_path=args.output_sif_path, 
             input_file_path2=args.input_genes,
             properties=properties)

if __name__ == '__main__':
    main()

# 12. Complete documentation strings



""" Common functions for package guild """
import os
import pandas as pd
import igraph as ig
import json
import requests
import subprocess
import urllib.request
from pathlib import Path, PurePath
from biobb_common.tools import file_utils as fu


def check_output(path, argument, out_log, classname):
    """ Checks output file """
    if PurePath(path).parent and not Path(PurePath(path).parent).exists():
        fu.log(classname + ': Unexisting %s folder, exiting' % argument, out_log)
        raise SystemExit(classname + ': Unexisting %s folder' % argument)
    file_extension = PurePath(path).suffix
    if not is_valid_file(file_extension[1:], argument):
        fu.log(classname + ': Format %s in %s file is not compatible' % (file_extension[1:], argument), out_log)
        raise SystemExit(classname + ': Format %s in %s file is not compatible' % (file_extension[1:], argument))
    return path

def check_mandatory_property(properties, name, out_log, classname):
    #check if the retrieve_by option is definied in the property, so to see if the required one is present
    """ Checks mandatory properties """
    for key in properties.keys():
        print (key)
        print ('name:', name)
        if str(name) in key:
        #if the property in the keys, check if the value is not null
            fu.log(classname + ': Parameter %s required present' % name, out_log)
            continue
        else:
            fu.log(classname + ': Unexisting %s property, exiting' % name, out_log)
            raise SystemExit(classname + ': Unexisting %s property' % name)
    return True


def is_valid_dir(output_path, out_log, global_log):
    if not os.path.exists(output_path):
        os.makedirs(output_path)

def is_valid_file(ext, argument):
    formats = {
            'output_sif': ['sif'],
            'output_csv': ['csv']
            }
    return ext in formats[argument]

def gda_session(association_type, retrieve_by, properties, out_log = None, global_log=None):
    for key in properties.keys():
        if retrieve_by+'_id' in key:
            identificator = key
            #Source case can be either gene_id or disease_id
        elif 'id' in key:
            identificator = key
    print ('idnetificator:', identificator)
    if retrieve_by:
        if retrieve_by == "disease" and properties.get("vocabulary"):
            request = os.path.join(association_type, retrieve_by, properties.get("vocabulary").strip(), properties[identificator])
        elif retrieve_by == "source" and properties.get("source"):
                #none of them is defined
            request = os.path.join(association_type, retrieve_by, properties.get("source").strip())
        elif retrieve_by == "uniprot":
            request = os.path.join(association_type+"/gene", retrieve_by, properties[identificator])
        elif retrieve_by == "evidences":
            #can have 3 different choices, variant, disease and gene (would be in the id property!)
            spx = identificator.split('id')[0]
            request = os.path.join(association_type, retrieve_by+"/"+spx, properties[identificator])
        else:
            request = os.path.join(association_type, retrieve_by, properties.get(identificator))
    else:
        raise SystemError('Error in the input parameter, check the specifics for each session requested.')
    fu.log("Request: %s" %(request), out_log)
    return request


def extension_request(request, retrieve_by, properties = None, out_log = None, global_log=None):
    #Not to include all the properties that are already present in the request
    new_keys={}
    for k in properties.keys():
        #fu.log("Prop %s" %(properties.keys()))
        if any(sub in str(k) for sub in request.split('/')):
            continue
        elif any(str(sub) in str(properties[k]) for sub in request.split('/')):
            continue
        else:
            new_keys[k] = properties[k]
    fu.log("New Keys %s" % (new_keys), out_log)
    ext=""
    for p, prop in enumerate(new_keys):
        fu.log("Prop %s and p %s" %(p, prop), out_log)
        if p != len(new_keys) - 1:
            #fu.log('Different key %s' % (prop), out_log)
            ext += str(prop) + "=" + str(new_keys.get(prop)) + "&"
        else:
            ext += str(prop) + "=" + str(new_keys.get(prop))
    #fu.log("ext %s" %(ext), out_log)
    if ext == "":
        pass
    else:
        request += "?"+ext
        fu.log("Final req %s" %(request), out_log)

    return new_keys, request

def auth_session(request, properties, email, password, output_path, out_log=None, global_log=None):
#    auth_params = {"email": args.email,"password": args.password}
    #email = getpass.getpass('E-mail:')
    #password = getpass.getpass('Password:')
    #print (request, properties, email, password, output_path)
    if not email:
        raise SystemError ("Credentials not provided, please check configuration.")
    else:
        auth_params = {"email":email,"password":password}
        api_host = "https://www.disgenet.org/api"
        api_key = None
        s = requests.Session()
        try:
            r = s.post(api_host+"/auth/", json=auth_params)
            if(r.status_code == 200):
            #Lets store the api key in a new variable and use it again in new requests
                json_response = r.json()
                api_key = json_response.get("token")
                print("This is your user API key: {}".format(api_key)) #Comment this line if you don't want your API key to show up in the terminal
            else:
                print(r.status_code)
                print(r.text)
        except requests.exceptions.RequestException as req_ex:
            print(req_ex)
            print("Something went wrong with the request.")
    #return api_key
        if api_key:
        #Add the api key to the requests headers of the requests Session object in order to use the restricted endpoints.
            s.headers.update({"Authorization": "Bearer %s" % api_key})
        #Lets get all the diseases associated to a gene eg. APP (EntrezID 351) and restricted by a source.
        #request = str(api_host+'/'+association_type+'/'+retrieve_by+'/'+properties[retrieve_by])
            req = api_host +'/' +str(request)
        #fu.log("Request %s " % req, out_log)
        #fu.log("Request %s " % request, out_log)
        #fu.log ("Prop %s" % properties, out_log)
            gda_response = s.get(req, params=properties)
            fu.log("Request %s launched, compiling" % req, out_log)
        #response_txt = gda_response.text
        #response_json = gda_response.json()
            #format_output = properties['format']
            #if format_output == "json":
            fu.log("Output file format: json", out_log, global_log)
            response_json = gda_response.json()
            file_json = write_output_json(response_json, 'json', output_path)
            #elif format_output == "tsv":
            #    fu.log("Output file format: %s" % (format_output), out_log, global_log)
            #    response_txt = gda_response.text
            #    write_output_txt(response_txt, format_output, output_path)
            #else: 
            #    fu.log("Output file format: %s" % (format_output), out_log, global_log)
            #    response_content = gda_response.content
            #    write_output_xml(response_content, format_output, output_path)
            fu.log("File json: %s" % (file_json), out_log, global_log)
            #fu.log("Format %s" % (format_output), out_log, global_log)

        if s:
            s.close()

def parse_hippie(hippie_db, hippie_genes, hippie_score, output_sif, out_log, global_log):
    """ Creates pd dataframe from Hippie Network and Hippie Genes """
    hippie = pd.read_csv(hippie_db, sep='\t',low_memory=False)
    hippie.columns=[x.replace(" ", "_") for x in hippie.columns]
    edges=hippie[hippie.Confidence_Value >= hippie_score ] 
    edges['ID_Interactor_A']=edges['ID_Interactor_A'].apply(lambda x: x.replace('entrez gene:',''))
    edges['ID_Interactor_B']=edges['ID_Interactor_B'].apply(lambda x: x.replace('entrez gene:',''))
    genes=pd.read_csv(hippie_genes,sep='\t')
    genes.GeneID=genes.GeneID.apply(lambda x: convert_to_str(x))
    #keep only the genes present in the human genes database
    edges = edges[(edges.ID_Interactor_A.isin(genes.GeneID.tolist()))&(edges.ID_Interactor_B.isin(genes.GeneID.tolist()))]
    #build a list of single genes to be used as nodes
    nodes=pd.DataFrame(set(edges.ID_Interactor_A.tolist()).union(edges.ID_Interactor_B.tolist()),columns=['Nodes'])
    graph_full=ig.Graph.DataFrame(edges, directed=False, vertices=nodes)
#    graph_full.ecount(),graph_full.vcount()#(104249, 13631)
    simplified_graph=ig.Graph.simplify(graph_full)
#    simplified_graph.ecount(),graph_full.vcount()#(101820, 13631)
    aux=ig.Graph.clusters(simplified_graph)#list the clusters of the graph 
    largest_cluster_index=list(aux.sizes()).index(max(list(aux.sizes()))) # gives the cluster number with the largest connected component
    nodes_in_largest_cluster=aux[largest_cluster_index]# returns the genes in the LCC
    gc1=ig.Graph.induced_subgraph(simplified_graph,nodes_in_largest_cluster) # creates a subgraph with the genes in the LCC
#    gc1.vcount(), gc1.ecount() # 13443  101755

    #store the edges in the dataframe and replace the node id (number of the node from (0-N) with edge name (entrez of the given gene
    ve=gc1.get_vertex_dataframe()
    ed=gc1.get_edge_dataframe()
    ed['source'].replace(ve['name'], inplace=True)
    ed['target'].replace(ve['name'], inplace=True)

    ed.insert(1,'scores',1) #insert the score column between edges for guild
    ed.to_csv(output_sif,index=False,header=False, sep=' ')#save the file 

def convert_to_str(integer):
    return str(integer)

def maknodes(interactome_sif, gda_result, disease_id, gda_score, scoring_mode, output_nodes, out_log, global_log, curated=False):
    ppi_network_edges = pd.read_csv(interactome_sif, sep=' ')
    ppi_network_edges.columns=['source','score','target']
    GdaDataset = pd.read_csv(gda_result, sep='\t')
    GeneColumn='geneid'
    ScoreColumn='gene_dsi'
    DisColumn='diseaseid'

#    if curated=='True':
#        GdaDataset=pd.read_csv("./biobb_guild/disc4all-data-fra/datasets/curated_gda.tsv",sep='\t')
#        GeneColumn='Gene_id'
#        ScoreColumn='Score_gda'
#        DisColumn='Disease_id'
#    else:
#        GdaDataset=pd.read_csv("./biobb_guild/disc4all-data-fra/datasets/all_gda.tsv",sep='\t')
#        GeneColumn='geneId'
#        ScoreColumn='score'
#        DisColumn='diseaseId'
    #GdaDataset=GdaDataset[(GdaDataset[ScoreColumn]>=gda_score)&(GdaDataset[DisColumn]==disease_id)] 
    seeds=GdaDataset[[GeneColumn, ScoreColumn]]
    seeds=seeds[(seeds[GeneColumn].isin(ppi_network_edges.source) | (seeds[GeneColumn].isin(ppi_network_edges.target)))]
    nodes=pd.DataFrame(set(ppi_network_edges.source.tolist() + ppi_network_edges.target.tolist()),columns=[GeneColumn])
    nodes_wo_seeds=pd.DataFrame([node for node in nodes[GeneColumn].tolist() if node not in seeds[GeneColumn].tolist()],columns=[GeneColumn])
    nodes_wo_seeds[ScoreColumn]=0
    if scoring_mode=='dis':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)
    elif scoring_mode=='norm_dis':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        ScoreMax=nodes[ScoreColumn].max()
        ScoreMin=nodes[ScoreColumn].min()
        nodes[ScoreColumn]=nodes[ScoreColumn].apply(lambda x: (x-ScoreMin)/(ScoreMax-ScoreMin))
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)
    elif scoring_mode == 'binary':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        nodes[ScoreColumn]=[1 if score > 0 else 0 for score in nodes[ScoreColumn].tolist()]
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)

def maknodes1(interactome_sif, gda_result, disease_id, gda_score, scoring_mode, dataset_path, output_nodes, out_log, global_log, curated=False):
    print ('Path:', os.getcwd())
    ppi_network_edges = pd.read_csv(interactome_sif, sep=' ')
    ppi_network_edges.columns=['source','score','target']
    if os.path.exists(dataset_path):
        if curated=='True':
            print ('PATH', os.path.join(dataset_path,"curated_gda.tsv"))
            GdaDataset=pd.read_csv(os.path.join(dataset_path,"curated_gda.tsv"),sep='\t')
            GeneColumn='Gene_id'
            ScoreColumn='Score_gda'
            DisColumn='Disease_id'
        else:
            print ('PATH', os.path.join(dataset_path,"all_gda.tsv"))
            GdaDataset=pd.read_csv(os.path.join(dataset_path,"all_gda.tsv"),sep='\t')
            GeneColumn='geneId'
            ScoreColumn='score'
            DisColumn='diseaseId'
        GdaDataset=GdaDataset[(GdaDataset[ScoreColumn]>=gda_score)&(GdaDataset[DisColumn]==disease_id)]
    else:
        raise ValueError('Dataset path not correct, {} not redirecting to GDA dataset.'.format(dataset_path))
    seeds=GdaDataset[[GeneColumn, ScoreColumn]]
    seeds=seeds[(seeds[GeneColumn].isin(ppi_network_edges.source) | (seeds[GeneColumn].isin(ppi_network_edges.target)))]
    nodes=pd.DataFrame(set(ppi_network_edges.source.tolist() + ppi_network_edges.target.tolist()),columns=[GeneColumn])
    nodes_wo_seeds=pd.DataFrame([node for node in nodes[GeneColumn].tolist() if node not in seeds[GeneColumn].tolist()],columns=[GeneColumn])
    nodes_wo_seeds[ScoreColumn]=0
    if scoring_mode=='dis':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)
    elif scoring_mode=='norm_dis':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        ScoreMax=nodes[ScoreColumn].max()
        ScoreMin=nodes[ScoreColumn].min()
        nodes[ScoreColumn]=nodes[ScoreColumn].apply(lambda x: (x-ScoreMin)/(ScoreMax-ScoreMin))
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)
    elif scoring_mode == 'binary':
        nodes=pd.concat([seeds,nodes_wo_seeds])
        nodes[ScoreColumn]=[1 if score > 0 else 0 for score in nodes[ScoreColumn].tolist()]
        nodes.to_csv(output_nodes, sep=' ', index=False, header=False)



def run_netscore(guild_ex, nodes, interactome, output_path, r=3, i=2):
    print ('bash -c " %s/./guild_x64 -s s -n %s -e %s -o %s -r %s -i %s"' % (guild_ex, nodes, interactome, output_path,r,i))
    subprocess.run('bash -c " %s/./guild_x64 -s s -n %s -e %s -o %s -r %s -i %s"' % (guild_ex, nodes, interactome, output_path,r,i),shell=True)
#source actovate guildmaster &&
def create_randomized_networks(guild_ex, interactome, output_path, n=100):
    subprocess.call('bash -c "python %s %s %s"' %(guild_ex,interactome,n),
                   shell=True)
    subprocess.run('mv %s.* %s'%(interactome, output_path),shell=True)
def run_netzcore(guild_ex, nodes, interactome, rand_interactomes, output_path,i=5):
    subprocess.run('bash -c "%s/./guild_x64 -s z -n %s -e %s -o %s -i %s -d %s -x 100"' % (guild_ex, nodes, interactome, output_path,i,rand_interactomes),shell=True)

def guild(algorithm, path_guild, nodes, interactome, output_path, out_log, global_log):
    if algorithm == "s":
        if not os.path.exists(output_path):
            os.makedirs(output_path)
            run_netscore(path_guild, nodes, interactome, output_path+"/output_netScore")
    elif algorithm == "z":
        rand_net = path_guild+"/RandomizedNetworks/"
        if not os.path.exists(rand_net):
            os.makedirs(rand_net)
        if len(os.listdir(rand_net))==0:
            rand_interactomes = create_randomize_networks(path_guild+"/src/create_random_networks_for_netzcore.py", interactome)
        run_netzcore(path_guild, nodes, interactome, rand_interactomes, output_path)

def convert_file(output_file_tc, output_file_c, format_file, out_log=None, global_log=None):
    fu.log("To convert: %s " % (output_file_tc))
    jsondata = open(output_file_tc)
    jdata = json.load(jsondata)
    df = pd.DataFrame.from_records(jdata)
    #fu.log("pd %s" %(df.T))
    #header = ["diseaseid", "variantid", "score"]
    df.to_csv(output_file_c+format_file, index=False, sep='\t', mode="a")

def write_output_json(response, format_output_file, output_path, out_log=None, global_log=None):
    #Function to write the file and download it in the format that is chosen by the user
    output_file = output_path+"."+format_output_file
    with open(output_file, "w", encoding='utf-8') as output:
        json.dump(response, output, ensure_ascii=False, indent=4)

    return (output_file)




#!/usr/bin/env python3

"""Module containing the BioBBs DisGeNET class and the command line interface."""
import argparse
import shutil
from pathlib import PurePath
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import  settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger
from biobb_guild.guild.common import *


# 1. Rename class as required
class GDA_disgenet(BiobbObject):
    """
    | biobb_disgenet Gene Disease Association Disgenet
    | This class is for downloading a Gene Disease Associations file from DisGeNET database.
    | Wrapper for the DisGeNET database `https://www.disgenet.org` and the  DisGeNET REST API ´https://www.disgenet.org/api/´ for downloading available collections of genes and variants associated data to human diseases.

    Args:
        retrieve_by (str): Configuration params to pass for the retrieval of the association on the REST API (gene, uniprot_entry, disease, source, evidences_gene, evidences_disease)  
        output_file_path (str): Path to the output file, that can be in format TSV, JSON or XML. 
        properties (dict - Python dict containing the properties for the API interrogation, considering also the credentials of the user to the database):
            * **gene_id** (*str*) - Number identification for a gene or a list of genes separated by commas recognized by the database.
            * **disease** (*str*) - Disease id or a list of disease separated by commas.
            * **disease_type** (*str*) - Disease, phenotype, group.
            * **source** (*str*) - Source of the associations (CURATED, INFERRED, ANIMAL_MODELS, ALL, BEFREE, CGI, CLINGEN, CLINVAR, CTD_human, CTD_mouse, CTD_rat, GENOMICS_ENGLAND, GWASCAT, GWASDB, HPO, LHGDN, MGD, ORPHANET, PSYGENET, RGD, UNIPROT).
            * **disease_vocabulary** (*str*) - Disease vocabulary (icd9cm, icd10, mesh, omim, do, efo, nci, hpo, mondo, ordo).
            * **disease_class** * - MeSh disease classes.
            * **min_score** (*str*) -  Min value of the gene-disease score range.
            * **max_score** (*str*) -  Max value of the gene-disease score range.
            * **min_ei** (*str*) -  Min value of evidence index score range.
            * **max_ei** (*str*) -  Max value of evidence index score range.
            * **max_dsi** (*str*) - Max value of DSI range for the gene.
            * **min_dsi** (*str*)  - Min value of DSI range for the gene.
            * **max_pli** (*str*) -  Max value of pLI range for the gene.
            * **min_pli** (*str*) -  Min value of pLI range for the gene.
            * **format** (*str*) - Format output file.
            * **limit** (*str*) - Number of GDAs to retrieve.
            * **min_year** (*str*) - The year of the earliest publications.
            * **max_year** (*str*) - The year of the latest publicatons.
            * **offset** (*str*) - Starting offset of the page.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python:

            from biobb_disgenet.disgenet.gda_disgenet import gda_disgenet

            prop = { 
                'gene_id': 'gene_id',
                'disease_id': 'disease_id',
                'uniprot_id': 'uniprot_id',
                'source': 'source', 
                'min_score': 'min_score',
                'max_score': 'max_score',
                'min_ei': 'min_ei',
                'max_ei': 'max_ei',
                'type': 'disease_type',
                'disease_class': 'disease_class',
                'min_dsi': 'min_dsi',
                'max_dsi': 'max_dsi',
                'min_dpi': 'min_dpi',
                'max_dpi': 'max_dpi',
                'min_pli': 'min_pli',
                'max_pli':'max_pli', 
                'format': 'format',
                'limit': 'limit',
                'min_year':'min_year',
                'max_year':'max_year',
                'offset':'offset'
            }
            gda_disgenet(retrieve_by='gene',
                    output_file_path='output_gene_351',
                    properties=prop)
    Info:

        retrieve_by can be: 
            gene, uniprot, source, evidences

    """

    # 2. Adapt input and output file paths as required. Include all files, even optional ones
    def __init__(self, input_file_path, output_csv_path,
                properties = None, **kwargs) -> None:
        properties = properties or {}
        
        print ('prova proprieta nel biobb', properties)
        # 2.0 Call parent class constructor
        super().__init__(properties)

        # 2.1 Modify to match constructor parameters
        # Input/Output files
        self.io_dict = { 
                'in': {'input_file_path': input_file_path}, 
            'out': { 'output_csv_path': output_csv_path } 
        }

        # 3. Include all relevant properties here as 
        # self.property_name = properties.get('property_name', property_default_value)

        # Properties specific for BB
        bb_properties = {}
        
        self.email = properties.get('email', None)
        self.password = properties.get('password', None)

        #print (properties)
        #print (self.email, self.password)

        bb_properties["gene_id"] = properties.get('gene_id', None)
        bb_properties["retrieve_by"] = properties.get('retrieve_by', None)
        bb_properties["disease_id"] = properties.get('disease_id', None)
        bb_properties["source"] = properties.get('source', "ALL") 
        bb_properties["vocabulary"] = properties.get('vocabulary', None)
        bb_properties["min_score"] = properties.get('min_score', None)
        bb_properties["max_score"] = properties.get('max_score', None)
        bb_properties["min_ei"] = properties.get('min_ei', None)
        bb_properties["max_ei"] = properties.get('max_ei', None)
        bb_properties["type"] = properties.get('disease_type', None)
        bb_properties["disease_class"] = properties.get('disease_class', None)
        bb_properties["min_dsi"] = properties.get('min_dsi', None)
        bb_properties["max_dsi"] = properties.get('max_dsi', None)
        bb_properties["max_dpi"] = properties.get('max_dpi', None)
        bb_properties["min_dpi"] = properties.get('min_dpi', None)
        bb_properties["max_pli"] = properties.get('max_pli', None)
        bb_properties["min_pli"] = properties.get('min_pli', None)
        bb_properties["format"] = properties.get('format', "json")
        bb_properties["limit"] = properties.get('limit', None)
        bb_properties["min_year"] = properties.get('min_year', None)
        bb_properties["max_year"] = properties.get('max_year',None)
        bb_properties["offset"] = properties.get('offset', None)
        bb_filtered = {k: v for k, v in bb_properties.items() if v is not None}
        bb_properties.clear()
        bb_properties.update(bb_filtered)
        self.properties = bb_properties

        #self.check_properties(properties)

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`GDA_disgenet <disgenet.GDA_disgenet.GDA_disgenet>` object."""
        
        # 4. Setup Biobb
        if self.check_restart(): return 0
        self.stage_files()
        
        #self.check_data_params(self.out_log, self.err_log)

        #Check if the output path exists and mandatory params are there
        check_output(self.io_dict['out']['output_csv_path'], "output_csv", self.out_log, self.__class__.__name__ )
        #check_mandatory_property(self.properties, 'retrieve_by', self.out_log, self.__class__.__name__) 
        #Authorized the session based on the session request
        if self.properties.get('retrieve_by'):
            print (self.properties.get('retrieve_by'))
            response = gda_session("gda", self.properties.get('retrieve_by'), self.properties, self.out_log, self.global_log)
        else:
            raise SystemExit("Fundamental argument is missing, check the input parameter.")
        print ('response:', response) 
        print ('input:', self.io_dict["in"]["input_file_path"])
        new_keys, request = extension_request(response, self.properties.get('retrieve_by'), self.properties)
        print (self.properties)
        print ('request: ', request)
        auth_session(request, new_keys, 'maria.ferri@bsc.es', 'mferri2021', self.io_dict['out']['output_csv_path'].split('.')[0], self.out_log, self.global_log)       
        file = self.io_dict['out']['output_csv_path'].split('.')[0]
        print (file)
        if os.path.isfile(file+".json"):
            #print (self.io_dict["out"]["output_csv_path"]+".json")
            convert_file(file+".json", file, ".csv", self.out_log, self.global_log)
        return 0

def gda_disgenet(input_file_path: str, output_csv_path: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Template <template.template.Template>` class and
    execute the :meth:`launch() <template.template.Template.launch>` method."""

    return GDA_disgenet(
                    input_file_path=input_file_path,
                    output_csv_path=output_csv_path,
                    properties=properties, **kwargs).launch()

def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='This class is a wrapper for an associations call of teh DisGeNET database REST API.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('--config', required=False, help='Configuration file')

    # 10. Include specific args of each building block following the examples. They should match step 2
    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('-input_file_path', required=True, help='Retrieval factor necessary to define the search of the associations; gene, uniprot entry, disease, source, evidence by disease, evidence by gene available choices.')
    required_args.add_argument('-output_csv_path', required=True, help='Description for the output file path. Accepted formats: json, csv or html.')
    #required_args.add_argument('-email',  required=True)
    #required_args.add_argument('-password',  required=True)
    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    # 11. Adapt to match Class constructor (step 2)
    # Specific call of each building block
    gda_disgenet(
             input_file_path=input_file_path,
             output_csv_path=output_csv_path,
             properties=properties)

if __name__ == '__main__':
    main()

# 12. Complete documentation string





#!/usr/bin/env python3

"""Module containing the Template class and the command line interface."""
import argparse
import pandas as pd
import numpy as np
import os
import shutil
from pathlib import PurePath
from biobb_guild.guild.common import *
from biobb_common.generic.biobb_object import BiobbObject
from biobb_common.configuration import  settings
from biobb_common.tools import file_utils as fu
from biobb_common.tools.file_utils import launchlogger


# 1. Rename class as required
class Nodes(BiobbObject):
    """
    | biobb_template Parse Hippie

    Args:        
        input_file_path1 (str): Hippie Database. Accepted formats: txt.
        input_file_path2 (str): Hippie Genes
        output_file_path (str): Description for the output file path. File type: output. `Sample file <https://urlto.sample>`_. Accepted formats: zip (edam:format_3987).
        properties (dic):
            * **boolean_property** (*bool*) - (True) Example of boolean property.
            * **executable_binary_property** (*str*) - ("zip") Example of executable binary property.
            * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
            * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.

    Examples:
        This is a use example of how to use the building block from Python::

            from biobb_template.template.template import template

            prop = { 
                'boolean_property': True 
            }
            template(input_file_path1='/path/to/myTopology.top',
                    output_file_path='/path/to/newCompressedFile.zip',
                    input_file_path2='/path/to/mytrajectory.dcd',
                    properties=prop)

    Info:
        * wrapped_software:
            * name: Zip
            * version: >=3.0
            * license: BSD 3-Clause
        * ontology:
            * name: EDAM
            * schema: http://edamontology.org/EDAM.owl

    """

    # 2. Adapt input and output file paths as required. Include all files, even optional ones
    def __init__(self, input_file_path1, input_file_path2, input_file_dataset, output_sif_path,
                properties = None, **kwargs) -> None:
        properties = properties or {}

        # 2.0 Call parent class constructor
        super().__init__(properties)

        # 2.1 Modify to match constructor parameters
        # Input/Output files
        self.io_dict = { 
            'in': { 'input_file_path1': input_file_path1 , 'input_file_path2': input_file_path2, 'input_file_dataset': input_file_dataset}, 
            'out': { 'output_sif_path': output_sif_path } 
        }

        # 3. Include all relevant properties here as 
        # self.property_name = properties.get('property_name', property_default_value)

        # Properties specific for BB
        self.curated = properties.get('curated', False)
        self.disease = properties.get('disease', '')
        #self.hippie_score = properties.get('hippie_score', 0.0)
        self.disgenet_score = properties.get('disgenet_score', 0.0)
        self.scoring_mode = properties.get('scoring_mode', 'dis')
        self.properties = properties

        # Check the properties
        self.check_properties(properties)

    @launchlogger
    def launch(self) -> int:
        """Execute the :class:`Template <template.template.Template>` object."""

        # 4. Setup Biobb
        if self.check_restart(): return 0
        self.stage_files()

        # Creating temporary folder
        self.tmp_folder = fu.create_unique_dir()
        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)

        check_output(self.io_dict['out']['output_sif_path'], "output_sif", self.out_log,self.__class__.__name__)
        maknodes1(self.io_dict['in']['input_file_path1'], self.io_dict['in']['input_file_path2'], self.disease, self.disgenet_score, self.scoring_mode, self.io_dict['in']['input_file_dataset'], self.io_dict['out']['output_sif_path'], self.out_log, self.global_log, curated=self.curated) 

        return 0

def nodes(input_file_path1: str, input_file_path2: str, input_file_dataset: str, output_sif_path: str, properties: dict = None, **kwargs) -> int:
    """Create :class:`Template <template.template.Template>` class and
    execute the :meth:`launch() <template.template.Template.launch>` method."""

    return Nodes(input_file_path1=input_file_path1,
                input_file_path2=input_file_path2,
                input_file_dataset=input_file_dataset,
                output_sif_path=output_sif_path,
                properties=properties, **kwargs).launch()

def main():
    """Command line execution of this building block. Please check the command line documentation."""
    parser = argparse.ArgumentParser(description='Description for the template module.', formatter_class=lambda prog: argparse.RawTextHelpFormatter(prog, width=99999))
    parser.add_argument('-c','--config', required=True, help='Configuration file')

    # 10. Include specific args of each building block following the examples. They should match step 2
    required_args = parser.add_argument_group('required arguments')
    required_args.add_argument('-i','--input_interactome', required=True, help='Description for the first input file path.')
    required_args.add_argument('-g','--input_gda', required=True, help='Description for the first input file path.')
    required_args.add_argument('-d','--dataset_path', required=True, help='Description for the dataset input file path.')
    required_args.add_argument('-o','--output_sif_path', required=True, help='Description for the output file path. Accepted formats: zip.')

    args = parser.parse_args()
    args.config = args.config or "{}"
    properties = settings.ConfReader(config=args.config).get_prop_dic()

    # 11. Adapt to match Class constructor (step 2)
    # Specific call of each building block
    nodes(input_file_path1=args.input_interactome,
             input_file_path2=args.input_gda,
             input_file_dataset=args.dataset_path,
             output_sif_path=args.output_sif_path, 
             properties=properties)

if __name__ == '__main__':
    main()

# 12. Complete documentation strings
